==> krita_4.1.7+dfsg.orig.tar.xz: krita-4.1.7.101/plugins/tools/tool_transform2/kis_liquify_paint_helper.h <==
/*
 *  Copyright (c) 2014 Dmitry Kazakov <dimula73@gmail.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#ifndef __KIS_LIQUIFY_PAINT_HELPER_H
#define __KIS_LIQUIFY_PAINT_HELPER_H

#include <QScopedPointer>

class KisLiquifyTransformWorker;
class KisCoordinatesConverter;
class KoPointerEvent;
class KisLiquifyProperties;
class QPainterPath;
class KoCanvasResourceManager;

class KisLiquifyPaintHelper
{
public:
    KisLiquifyPaintHelper(const KisCoordinatesConverter *converter);
    ~KisLiquifyPaintHelper();

    void configurePaintOp(const KisLiquifyProperties &_props,
                          KisLiquifyTransformWorker *worker);

    void startPaint(KoPointerEvent *event, const KoCanvasResourceManager *manager);
    void continuePaint(KoPointerEvent *event);
    bool endPaint(KoPointerEvent *event);

    void hoverPaint(KoPointerEvent *event);

    QPainterPath brushOutline(const KisLiquifyProperties &props);

private:
    struct Private;
    const QScopedPointer<Private> m_d;
};

#endif /* __KIS_LIQUIFY_PAINT_HELPER_H */

==> krita_4.4.2+dfsg.orig.tar.xz: krita-4.4.2/plugins/tools/tool_transform2/kis_liquify_paint_helper.h <==
/*
 *  Copyright (c) 2014 Dmitry Kazakov <dimula73@gmail.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#ifndef __KIS_LIQUIFY_PAINT_HELPER_H
#define __KIS_LIQUIFY_PAINT_HELPER_H

#include <QScopedPointer>

class KisLiquifyTransformWorker;
class KisCoordinatesConverter;
class KoPointerEvent;
class KisLiquifyProperties;
class QPainterPath;
class KoCanvasResourceProvider;

class KisLiquifyPaintHelper
{
public:
    KisLiquifyPaintHelper(const KisCoordinatesConverter *converter);
    ~KisLiquifyPaintHelper();

    void configurePaintOp(const KisLiquifyProperties &_props,
                          KisLiquifyTransformWorker *worker);

    void startPaint(KoPointerEvent *event, const KoCanvasResourceProvider *manager);
    void continuePaint(KoPointerEvent *event);
    bool endPaint(KoPointerEvent *event);

    void hoverPaint(KoPointerEvent *event);

    QPainterPath brushOutline(const KisLiquifyProperties &props);

private:
    struct Private;
    const QScopedPointer<Private> m_d;
};

#endif /* __KIS_LIQUIFY_PAINT_HELPER_H */
